==> syd-renzheng-1.0.0.tgz: package/test/test.js <==
const path = require('path');
const 认证 = require('../app.js');
const typeorm = require('typeorm');

describe('认证模块测试', function () {
    before(async () => {
        process.removeAllListeners('uncaughtException');

        try {
            await 认证.init({
                'type': 'mysql',
                'host': '127.0.0.1',
                'port': 3306,
                'username': 'root',
                'password': 'Abcd1234=',
                'database': 'renzheng',
                'synchronize': false,
                'entitySchemas': [
                    path.join(__dirname, '../entity/*.json')
                ]
            });
            await 认证.con.query('delete from s_公司表');
            await 认证.con.query('delete from s_用户登录记录');
            await 认证.con.query('delete from s_用户表');
            await 认证.con.query('delete from s_系统创建记录');
            await 认证.con.query('delete from s_门店表');
            console.log('清除数据成功');
        } catch (error) {
            console.log(error)
        }
    });
    after(function () {
        // 在本区块的所有测试用例之后执行
    });

    it('测试-注册', async () => {
        await 认证.注册({
            密码1: '123456',
            密码2: 123456,
            公司名称: '张三的公司',
            手机号: '13072406321',
            姓名: '张三',
            系统名称:'微会员',
            数据库配置:'asdfasdfasdfasdfasdasdfadsfasdfasdfadsdf'
        });
    });

    it('测试-登录', async () => {
        await 认证.登录({
            账号: '13072406321',
            密码: 123456,
            ip: '192.168.1.111'
        });
    });
    it('测试-获取一个公司', async () => {
        await 认证.获取一个公司(1);
    });
    it('测试-修改公司', async () => {
        await 认证.修改公司({
            I_公司编号: 1,
            C_公司名称: '修改过的张三的公司',
            C_地址: '幸福街',
            C_电话: '024-8888888'
        });

    });
    it('测试-创建系统', async () => {
        await 认证.创建系统({
            I_公司编号: 1,
            C_公司名称: '修改过的张三的公司',
            C_创建系统名称: '会员系统',
            I_创建用户编号: '1',
            C_创建用户名称: '李四'
        });
    });
    it('测试-创建门店', async () => {
        await 认证.创建门店({
            I_公司编号: 1,
            C_门店名称: '修改过的张三的公司1门店',
            I_门店类型: 2,
            I_上级编号: 0,
            C_电话:'',
            C_地址:''
        });
    });
    it('测试-获取门店列表', async () => {
        await 认证.获取门店列表(1);
    });
    it('测试-修改门店', async () => {
        await 认证.修改门店({
            I_公司编号: 1,
            C_门店名称: '修改过的张三的公司1门店',
            I_门店类型: 2,
            I_上级编号: 0,
            C_电话:'8888888',
            C_地址:''
        },1);
    });
    it('测试-创建用户', async () => {
        await 认证.创建用户({
            I_公司编号: 1,
            C_账号: '13072406322',
            C_密码: 123456
        });
    }); it('测试-获取用户列表', async () => {
        await 认证.获取用户列表(1);
    });
    it('测试-修改用户', async () => {
        await 认证.修改用户({
            I_公司编号: 1,
            C_姓名:'王二麻子'
        },2);
    }); it('测试-删除用户', async () => {
        await 认证.删除用户(1,2);
    });
});

==> syd-renzheng-1.1.4.tgz: package/test/test.js <==
const path = require('path');
const 认证 = require('../app.js');
const typeorm = require('typeorm');

describe('认证模块测试', function () {
    before(async () => {
        process.removeAllListeners('uncaughtException');

        try {
            await 认证.init({
                'type': 'mysql',
                'host': '127.0.0.1',
                'port': 3306,
                'username': 'root',
                'password': 'Abcd1234=',
                'database': 'renzheng',
                'synchronize': false,
                'entitySchemas': [
                    path.join(__dirname, '../entity/*.json')
                ]
            });
            await 认证.con.query('delete from s_公司表');
            await 认证.con.query('delete from s_用户登录记录');
            await 认证.con.query('delete from s_用户表');
            await 认证.con.query('delete from s_系统创建记录');
            await 认证.con.query('delete from s_门店表');
            console.log('清除数据成功');
        } catch (error) {
            console.log(error)
        }
    });
    after(function () {
        // 在本区块的所有测试用例之后执行
    });

    it('测试-注册', async () => {
        await 认证.注册({
            密码1: '123456',
            密码2: 123456,
            公司名称: '张三的公司',
            手机号: '13072406321',
            姓名: '张三',
            系统名称:'微会员',
            数据库配置:'asdfasdfasdfasdfasdasdfadsfasdfasdfadsdf'
        });
    });

    it('测试-登录', async () => {
        await 认证.登录({
            账号: '13072406321',
            密码: 123456,
            ip: '192.168.1.111'
        });
    });
    it('测试-获取一个公司', async () => {
        await 认证.获取一个公司(1);
    });
    it('测试-修改公司', async () => {
        await 认证.修改公司({
            I_公司编号: 1,
            C_公司名称: '修改过的张三的公司',
            C_地址: '幸福街',
            C_电话: '024-8888888'
        });

    });
    it('测试-创建系统', async () => {
        await 认证.创建系统({
            I_公司编号: 1,
            C_公司名称: '修改过的张三的公司',
            C_创建系统名称: '会员系统',
            I_创建用户编号: '1',
            C_创建用户名称: '李四'
        });
    });
    it('测试-创建门店', async () => {
        await 认证.创建门店({
            I_公司编号: 1,
            C_门店名称: '修改过的张三的公司1门店',
            I_门店类型: 2,
            I_上级编号: 0,
            C_电话:'',
            C_地址:''
        });
    });
    it('测试-获取门店列表', async () => {
        await 认证.获取门店列表(1);
    });
    it('测试-修改门店', async () => {
        await 认证.修改门店({
            I_公司编号: 1,
            C_门店名称: '修改过的张三的公司1门店',
            I_门店类型: 2,
            I_上级编号: 0,
            C_电话:'8888888',
            C_地址:''
        },1);
    });
    it('测试-创建用户', async () => {
        await 认证.创建用户({
            I_公司编号: 1,
            C_手机号: '13072406322',
            C_密码: 123456
        });
    }); it('测试-获取用户列表', async () => {
        await 认证.获取用户列表(1);
    });
    it('测试-修改用户', async () => {
        await 认证.修改用户({
            I_公司编号: 1,
            C_姓名:'王二麻子'
        },2);
    }); it('测试-删除用户', async () => {
        await 认证.删除用户(1,2);
    });
});
